==> magics++_4.10.1.orig.tar.xz: magics++-4.10.1/src/api/py_calls.h <==
extern "C" {
MAGICS_EXPORT const char* py_boxplot();
MAGICS_EXPORT const char* py_close();
MAGICS_EXPORT const char* py_coast();
MAGICS_EXPORT const char* py_cont();
MAGICS_EXPORT const char* py_epsbar();
MAGICS_EXPORT const char* py_epscloud();
MAGICS_EXPORT const char* py_epsgraph();
MAGICS_EXPORT const char* py_epsinput();
MAGICS_EXPORT const char* py_epslight();
MAGICS_EXPORT const char* py_epsplumes();
MAGICS_EXPORT const char* py_epsshading();
MAGICS_EXPORT const char* py_epswave();
MAGICS_EXPORT const char* py_epswind();
MAGICS_EXPORT const char* py_geojson();
MAGICS_EXPORT const char* py_grib();
MAGICS_EXPORT const char* py_image();
MAGICS_EXPORT const char* py_import();
MAGICS_EXPORT const char* py_input();
MAGICS_EXPORT const char* py_keep_compatibility();
MAGICS_EXPORT const char* py_knowndrivers();
MAGICS_EXPORT const char* py_legend();
MAGICS_EXPORT const char* py_line();
MAGICS_EXPORT const char* py_mapgen();
MAGICS_EXPORT const char* py_metagrib();
MAGICS_EXPORT const char* py_metainput();
MAGICS_EXPORT const char* py_metanetcdf();
MAGICS_EXPORT const char* py_metbufr();
MAGICS_EXPORT const char* py_metgraph();
MAGICS_EXPORT const char* py_mute();
MAGICS_EXPORT const char* py_netcdf();
MAGICS_EXPORT const char* py_obs();
MAGICS_EXPORT const char* py_odb();
MAGICS_EXPORT const char* py_open();
MAGICS_EXPORT const char* py_overlay();
MAGICS_EXPORT const char* py_plot();
MAGICS_EXPORT const char* py_raw();
MAGICS_EXPORT const char* py_set_python();
MAGICS_EXPORT const char* py_symb();
MAGICS_EXPORT const char* py_table();
MAGICS_EXPORT const char* py_taylor();
MAGICS_EXPORT const char* py_tephi();
MAGICS_EXPORT const char* py_text();
MAGICS_EXPORT const char* py_tile();
MAGICS_EXPORT const char* py_unmute();
MAGICS_EXPORT const char* py_wind();
MAGICS_EXPORT const char* py_wrepjson();
MAGICS_EXPORT const char* py_new(const char* page);
MAGICS_EXPORT const char* py_reset(const char* name);
MAGICS_EXPORT const char* py_setc(const char* name, const char* value);
MAGICS_EXPORT const char* py_setr(const char* name, const double value);
MAGICS_EXPORT const char* py_seti(const char* name, const int value);
MAGICS_EXPORT const char* py_set1r(const char* name, const double* data, const int dim1);
MAGICS_EXPORT const char* py_set2r(const char* name, const double* data, const int dim1, const int dim2);
MAGICS_EXPORT const char* py_set1i(const char* name, const int* data, const int dim1);
MAGICS_EXPORT const char* py_set2i(const char* name, const int* data, const int dim1, const int dim2);
MAGICS_EXPORT const char* py_set1c(const char* name, const char** data, const int dim1);
};

==> magics++_4.15.5.orig.tar.xz: magics++-4.15.5/src/api/py_calls.h <==
extern "C" {
MAGICS_EXPORT const char* py_boxplot();
MAGICS_EXPORT const char* py_close();
MAGICS_EXPORT const char* py_coast();
MAGICS_EXPORT const char* py_cont();
MAGICS_EXPORT const char* py_epsbar();
MAGICS_EXPORT const char* py_epscloud();
MAGICS_EXPORT const char* py_epsgraph();
MAGICS_EXPORT const char* py_epsinput();
MAGICS_EXPORT const char* py_epslight();
MAGICS_EXPORT const char* py_epsplumes();
MAGICS_EXPORT const char* py_epsshading();
MAGICS_EXPORT const char* py_epswave();
MAGICS_EXPORT const char* py_epswind();
MAGICS_EXPORT const char* py_geojson();
MAGICS_EXPORT const char* py_grib();
MAGICS_EXPORT const char* py_image();
MAGICS_EXPORT const char* py_import();
MAGICS_EXPORT const char* py_input();
MAGICS_EXPORT const char* py_keep_compatibility();
MAGICS_EXPORT const char* py_knowndrivers();
MAGICS_EXPORT const char* py_long_parameters(); 
MAGICS_EXPORT const char* py_legend();
MAGICS_EXPORT const char* py_line();
MAGICS_EXPORT const char* py_mapgen();
MAGICS_EXPORT const char* py_metagrib();
MAGICS_EXPORT const char* py_metainput();
MAGICS_EXPORT const char* py_metanetcdf();
MAGICS_EXPORT const char* py_metbufr();
MAGICS_EXPORT const char* py_metgraph();
MAGICS_EXPORT const char* py_mute();
MAGICS_EXPORT const char* py_netcdf();
MAGICS_EXPORT const char* py_obs();
MAGICS_EXPORT const char* py_odb();
MAGICS_EXPORT const char* py_open();
MAGICS_EXPORT const char* py_overlay();
MAGICS_EXPORT const char* py_plot();
MAGICS_EXPORT const char* py_raw();
MAGICS_EXPORT const char* py_set_python();
MAGICS_EXPORT const char* py_symb();
MAGICS_EXPORT const char* py_table();
MAGICS_EXPORT const char* py_taylor();
MAGICS_EXPORT const char* py_tephi();
MAGICS_EXPORT const char* py_text();
MAGICS_EXPORT const char* py_tile();
MAGICS_EXPORT const char* py_unmute();
MAGICS_EXPORT const char* py_wind();
MAGICS_EXPORT const char* py_wrepjson();
MAGICS_EXPORT const char* py_new(const char* page);
MAGICS_EXPORT const char* py_reset(const char* name);
MAGICS_EXPORT const char* py_setc(const char* name, const char* value);
MAGICS_EXPORT const char* py_setr(const char* name, const double value);
MAGICS_EXPORT const char* py_seti(const char* name, const int value);
MAGICS_EXPORT const char* py_setli(const char* name, const unsigned long long value);
MAGICS_EXPORT const char* py_set1r(const char* name, const double* data, const int dim1);
MAGICS_EXPORT const char* py_set2r(const char* name, const double* data, const int dim1, const int dim2);
MAGICS_EXPORT const char* py_set1i(const char* name, const int* data, const int dim1);
MAGICS_EXPORT const char* py_set2i(const char* name, const int* data, const int dim1, const int dim2);
MAGICS_EXPORT const char* py_set1c(const char* name, const char** data, const int dim1);
};
